@@ -9,4 +9,8 @@ NO_PASSWORD_RESET_FOUND = {
 THE_PASSWORD_IS_NOT_SECURE = {
 	"code" : BASE_ERROR_CODE | 2,
 	"message" : _("The password is not secure"),
+}
+EMAIL_IS_NOT_UNIQUE = {
+	"code" : BASE_ERROR_CODE | 3,
+	"message" : _("The email is not unique"),
 }
\ No newline at end of file
