@@ -1,5 +1,5 @@
 from django.db import models
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.core.exceptions import ObjectDoesNotExist
 from django.utils import timezone
 from django.utils.translation import ugettext as _
@@ -9,14 +9,12 @@ from . import managers
 from . import settings
 
 
-
 class PasswordReset(BaseModel):
-	user = models.ForeignKey(User)
-
+	user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete = models.CASCADE)
 	last_sent_date = models.DateTimeField(null = True, blank = True, default = None)
 	activation_date = models.DateTimeField(null = True, blank = True, default = None)
 	ip_address = models.GenericIPAddressField(null = True, blank = True, default = "")
-	code = models.CharField(max_length = settings.STRING_NORMAL, unique = True)
+	code = models.CharField(max_length = settings.PASSWORDRESET_CODE_MAX_LENGTH, unique = True)
 
 
 	def send_again(self):
